==> konos-12.2.12-sources.jar: io/intino/konos/dsl/Display.java <==
package io.intino.konos.dsl;

import io.intino.konos.dsl.*;

public class Display extends io.intino.konos.dsl.PassiveView implements io.intino.magritte.framework.tags.Terminal {
	protected java.util.List<io.intino.konos.dsl.Component> components = new java.util.ArrayList<>();
	protected java.lang.String parentDisplay;
	protected java.util.List<io.intino.konos.dsl.Block> blockList = new java.util.ArrayList<>();
	protected io.intino.konos.dsl.Display.Accessible _accessible;

	public Display(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public java.util.List<io.intino.konos.dsl.Component> components() {
		return components;
	}

	public io.intino.konos.dsl.Component components(int index) {
		return components.get(index);
	}

	public java.util.List<io.intino.konos.dsl.Component> components(java.util.function.Predicate<io.intino.konos.dsl.Component> predicate) {
		return components().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public java.lang.String parentDisplay() {
		return parentDisplay;
	}

	public Display parentDisplay(java.lang.String value) {
		this.parentDisplay = value;
		return (Display) this;
	}

	public java.util.List<io.intino.konos.dsl.Block> blockList() {
		return java.util.Collections.unmodifiableList(blockList);
	}

	public io.intino.konos.dsl.Block block(int index) {
		return blockList.get(index);
	}

	public java.util.List<io.intino.konos.dsl.Block> blockList(java.util.function.Predicate<io.intino.konos.dsl.Block> predicate) {
		return blockList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.konos.dsl.Block block(java.util.function.Predicate<io.intino.konos.dsl.Block> predicate) {
		return blockList().stream().filter(predicate).findFirst().orElse(null);
	}


	public io.intino.konos.dsl.Display.Accessible asAccessible() {
		io.intino.magritte.framework.Layer as = a$(io.intino.konos.dsl.Display.Accessible.class);
		return as != null ? (io.intino.konos.dsl.Display.Accessible) as : core$().addAspect(io.intino.konos.dsl.Display.Accessible.class);
	}

	public boolean isAccessible() {
		return core$().is(io.intino.konos.dsl.Display.Accessible.class);
	}

	public void removeAccessible() {
		core$().removeAspect(io.intino.konos.dsl.Display.Accessible.class);
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(blockList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
		map.put("components", this.components);
		map.put("parentDisplay", new java.util.ArrayList(java.util.Collections.singletonList(this.parentDisplay)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Block")) this.blockList.add(node.as(io.intino.konos.dsl.Block.class));
	}

	@Override
	protected void removeNode$(io.intino.magritte.framework.Node node) {
		super.removeNode$(node);
		if (node.is("Block")) this.blockList.remove(node.as(io.intino.konos.dsl.Block.class));
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("components")) this.components = io.intino.magritte.framework.loaders.NodeLoader.load(values,  io.intino.konos.dsl.Component.class, this);
		else if (name.equalsIgnoreCase("parentDisplay")) this.parentDisplay = io.intino.magritte.framework.loaders.StringLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("components")) this.components = ((java.util.List<java.lang.Object>) values).stream().
			map(s -> graph().core$().load(((io.intino.magritte.framework.Layer) s).core$().id()).as(io.intino.konos.dsl.Component.class)).collect(java.util.stream.Collectors.toList());
		else if (name.equalsIgnoreCase("parentDisplay")) this.parentDisplay = (java.lang.String) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.konos.dsl.PassiveView.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.konos.dsl.Block block() {
			io.intino.konos.dsl.Block newElement = core$().graph().concept(io.intino.konos.dsl.Block.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Block.class);

			return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear extends io.intino.konos.dsl.PassiveView.Clear {
		public void block(java.util.function.Predicate<io.intino.konos.dsl.Block> filter) {
			new java.util.ArrayList<>(blockList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}
	}

	public static class Accessible  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.util.List<java.lang.String> parameters = new java.util.ArrayList<>();
		protected java.util.List<java.lang.String> events = new java.util.ArrayList<>();
		protected boolean confidential;
		protected io.intino.konos.dsl.Display _display;

		public Accessible(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.util.List<java.lang.String> parameters() {
			return parameters;
		}

		public java.lang.String parameters(int index) {
			return parameters.get(index);
		}

		public java.util.List<java.lang.String> parameters(java.util.function.Predicate<java.lang.String> predicate) {
			return parameters().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		public java.util.List<java.lang.String> events() {
			return events;
		}

		public java.lang.String events(int index) {
			return events.get(index);
		}

		public java.util.List<java.lang.String> events(java.util.function.Predicate<java.lang.String> predicate) {
			return events().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		public boolean confidential() {
			return confidential;
		}

		public java.util.List<io.intino.konos.dsl.Component> components() {
			return _display.components();
		}

		public io.intino.konos.dsl.Component components(int index) {
			return _display.components().get(index);
		}

		public java.lang.String parentDisplay() {
			return _display.parentDisplay();
		}

		public Accessible confidential(boolean value) {
			this.confidential = value;
			return (Accessible) this;
		}

		public Accessible parentDisplay(java.lang.String value) {
			this._display.parentDisplay(value);
			return (Accessible) this;
		}

		public java.util.List<io.intino.konos.dsl.Block> blockList() {
			return (java.util.List<io.intino.konos.dsl.Block>) _display.blockList();
		}

		public io.intino.konos.dsl.Block blockList(int index) {
			return _display.blockList().get(index);
		}

		public java.util.List<io.intino.konos.dsl.PassiveView.Request> requestList() {
			return (java.util.List<io.intino.konos.dsl.PassiveView.Request>) _display.requestList();
		}

		public io.intino.konos.dsl.PassiveView.Request requestList(int index) {
			return _display.requestList().get(index);
		}

		public java.util.List<io.intino.konos.dsl.PassiveView.Notification> notificationList() {
			return (java.util.List<io.intino.konos.dsl.PassiveView.Notification>) _display.notificationList();
		}

		public io.intino.konos.dsl.PassiveView.Notification notificationList(int index) {
			return _display.notificationList().get(index);
		}
		public io.intino.konos.dsl.Display asDisplay() {
			return (io.intino.konos.dsl.Display) a$(io.intino.konos.dsl.Display.class);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("parameters", this.parameters);
			map.put("events", this.events);
			map.put("confidential", new java.util.ArrayList(java.util.Collections.singletonList(this.confidential)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("parameters")) this.parameters = io.intino.magritte.framework.loaders.StringLoader.load(values, this);
			else if (name.equalsIgnoreCase("events")) this.events = io.intino.magritte.framework.loaders.StringLoader.load(values, this);
			else if (name.equalsIgnoreCase("confidential")) this.confidential = io.intino.magritte.framework.loaders.BooleanLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("parameters")) this.parameters = new java.util.ArrayList<>((java.util.List<java.lang.String>) values);
			else if (name.equalsIgnoreCase("events")) this.events = new java.util.ArrayList<>((java.util.List<java.lang.String>) values);
			else if (name.equalsIgnoreCase("confidential")) this.confidential = (java.lang.Boolean) values.get(0);
		}

		@Override
		protected void sync$(io.intino.magritte.framework.Layer layer) {
			super.sync$(layer);
			if (layer instanceof io.intino.konos.dsl.Display) _display = (io.intino.konos.dsl.Display) layer;

		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}

			public io.intino.konos.dsl.Block block() {
				io.intino.konos.dsl.Block newElement = core$().graph().concept(io.intino.konos.dsl.Block.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Block.class);

				return newElement;
			}

			public io.intino.konos.dsl.PassiveView.Request request() {
				io.intino.konos.dsl.PassiveView.Request newElement = core$().graph().concept(io.intino.konos.dsl.PassiveView.Request.class).createNode(this.name, core$()).as(io.intino.konos.dsl.PassiveView.Request.class);

				return newElement;
			}

			public io.intino.konos.dsl.PassiveView.Notification notification() {
				io.intino.konos.dsl.PassiveView.Notification newElement = core$().graph().concept(io.intino.konos.dsl.PassiveView.Notification.class).createNode(this.name, core$()).as(io.intino.konos.dsl.PassiveView.Notification.class);

				return newElement;
			}

		}

		public Clear clear() {
			return new Clear();
		}

		public class Clear  {
			public void block(java.util.function.Predicate<io.intino.konos.dsl.Block> filter) {
				new java.util.ArrayList<>(blockList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}

			public void request(java.util.function.Predicate<io.intino.konos.dsl.PassiveView.Request> filter) {
				new java.util.ArrayList<>(requestList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}

			public void notification(java.util.function.Predicate<io.intino.konos.dsl.PassiveView.Notification> filter) {
				new java.util.ArrayList<>(notificationList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}


	public io.intino.konos.dsl.KonosGraph graph() {
		return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
	}
}

==> konos-13.6.5-sources.jar: io/intino/konos/dsl/Display.java <==
package io.intino.konos.dsl;

import io.intino.konos.dsl.*;

public class Display extends io.intino.konos.dsl.PassiveView implements io.intino.magritte.framework.tags.Terminal {
	protected java.util.List<io.intino.konos.dsl.Component> components = new java.util.ArrayList<>();
	protected java.lang.String parentDisplay;
	protected java.util.List<io.intino.konos.dsl.Block> blockList = new java.util.ArrayList<>();
	protected io.intino.konos.dsl.Display.Exposed _exposed;

	public Display(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public java.util.List<io.intino.konos.dsl.Component> components() {
		return components;
	}

	public io.intino.konos.dsl.Component components(int index) {
		return components.get(index);
	}

	public java.util.List<io.intino.konos.dsl.Component> components(java.util.function.Predicate<io.intino.konos.dsl.Component> predicate) {
		return components().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public java.lang.String parentDisplay() {
		return parentDisplay;
	}

	public Display parentDisplay(java.lang.String value) {
		this.parentDisplay = value;
		return (Display) this;
	}

	public java.util.List<io.intino.konos.dsl.Block> blockList() {
		return java.util.Collections.unmodifiableList(blockList);
	}

	public io.intino.konos.dsl.Block block(int index) {
		return blockList.get(index);
	}

	public java.util.List<io.intino.konos.dsl.Block> blockList(java.util.function.Predicate<io.intino.konos.dsl.Block> predicate) {
		return blockList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.konos.dsl.Block block(java.util.function.Predicate<io.intino.konos.dsl.Block> predicate) {
		return blockList().stream().filter(predicate).findFirst().orElse(null);
	}


	public io.intino.konos.dsl.Display.Exposed asExposed() {
		io.intino.magritte.framework.Layer as = a$(io.intino.konos.dsl.Display.Exposed.class);
		return as != null ? (io.intino.konos.dsl.Display.Exposed) as : core$().addAspect(io.intino.konos.dsl.Display.Exposed.class);
	}

	public boolean isExposed() {
		return core$().is(io.intino.konos.dsl.Display.Exposed.class);
	}

	public void removeExposed() {
		core$().removeAspect(io.intino.konos.dsl.Display.Exposed.class);
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(blockList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
		map.put("components", this.components);
		map.put("parentDisplay", new java.util.ArrayList(java.util.Collections.singletonList(this.parentDisplay)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Block")) this.blockList.add(node.as(io.intino.konos.dsl.Block.class));
	}

	@Override
	protected void removeNode$(io.intino.magritte.framework.Node node) {
		super.removeNode$(node);
		if (node.is("Block")) this.blockList.remove(node.as(io.intino.konos.dsl.Block.class));
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("components")) this.components = io.intino.magritte.framework.loaders.NodeLoader.load(values,  io.intino.konos.dsl.Component.class, this);
		else if (name.equalsIgnoreCase("parentDisplay")) this.parentDisplay = io.intino.magritte.framework.loaders.StringLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("components")) this.components = ((java.util.List<java.lang.Object>) values).stream().
			map(s -> graph().core$().load(((io.intino.magritte.framework.Layer) s).core$().id()).as(io.intino.konos.dsl.Component.class)).collect(java.util.stream.Collectors.toList());
		else if (name.equalsIgnoreCase("parentDisplay")) this.parentDisplay = (java.lang.String) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.konos.dsl.PassiveView.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.konos.dsl.Block block() {
			io.intino.konos.dsl.Block newElement = core$().graph().concept(io.intino.konos.dsl.Block.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Block.class);

			return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear extends io.intino.konos.dsl.PassiveView.Clear {
		public void block(java.util.function.Predicate<io.intino.konos.dsl.Block> filter) {
			new java.util.ArrayList<>(blockList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}
	}

	public static class Exposed  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected java.util.List<java.lang.String> parameters = new java.util.ArrayList<>();
		protected java.util.List<java.lang.String> events = new java.util.ArrayList<>();
		protected boolean confidential;
		protected io.intino.konos.dsl.Display _display;

		public Exposed(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public java.util.List<java.lang.String> parameters() {
			return parameters;
		}

		public java.lang.String parameters(int index) {
			return parameters.get(index);
		}

		public java.util.List<java.lang.String> parameters(java.util.function.Predicate<java.lang.String> predicate) {
			return parameters().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		public java.util.List<java.lang.String> events() {
			return events;
		}

		public java.lang.String events(int index) {
			return events.get(index);
		}

		public java.util.List<java.lang.String> events(java.util.function.Predicate<java.lang.String> predicate) {
			return events().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
		}

		public boolean confidential() {
			return confidential;
		}

		public java.util.List<io.intino.konos.dsl.Component> components() {
			return _display.components();
		}

		public io.intino.konos.dsl.Component components(int index) {
			return _display.components().get(index);
		}

		public java.lang.String parentDisplay() {
			return _display.parentDisplay();
		}

		public Exposed confidential(boolean value) {
			this.confidential = value;
			return (Exposed) this;
		}

		public Exposed parentDisplay(java.lang.String value) {
			this._display.parentDisplay(value);
			return (Exposed) this;
		}

		public java.util.List<io.intino.konos.dsl.Block> blockList() {
			return (java.util.List<io.intino.konos.dsl.Block>) _display.blockList();
		}

		public io.intino.konos.dsl.Block blockList(int index) {
			return _display.blockList().get(index);
		}

		public java.util.List<io.intino.konos.dsl.PassiveView.Request> requestList() {
			return (java.util.List<io.intino.konos.dsl.PassiveView.Request>) _display.requestList();
		}

		public io.intino.konos.dsl.PassiveView.Request requestList(int index) {
			return _display.requestList().get(index);
		}

		public java.util.List<io.intino.konos.dsl.PassiveView.Notification> notificationList() {
			return (java.util.List<io.intino.konos.dsl.PassiveView.Notification>) _display.notificationList();
		}

		public io.intino.konos.dsl.PassiveView.Notification notificationList(int index) {
			return _display.notificationList().get(index);
		}
		public io.intino.konos.dsl.Display asDisplay() {
			return (io.intino.konos.dsl.Display) a$(io.intino.konos.dsl.Display.class);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("parameters", this.parameters);
			map.put("events", this.events);
			map.put("confidential", new java.util.ArrayList(java.util.Collections.singletonList(this.confidential)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("parameters")) this.parameters = io.intino.magritte.framework.loaders.StringLoader.load(values, this);
			else if (name.equalsIgnoreCase("events")) this.events = io.intino.magritte.framework.loaders.StringLoader.load(values, this);
			else if (name.equalsIgnoreCase("confidential")) this.confidential = io.intino.magritte.framework.loaders.BooleanLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("parameters")) this.parameters = new java.util.ArrayList<>((java.util.List<java.lang.String>) values);
			else if (name.equalsIgnoreCase("events")) this.events = new java.util.ArrayList<>((java.util.List<java.lang.String>) values);
			else if (name.equalsIgnoreCase("confidential")) this.confidential = (java.lang.Boolean) values.get(0);
		}

		@Override
		protected void sync$(io.intino.magritte.framework.Layer layer) {
			super.sync$(layer);
			if (layer instanceof io.intino.konos.dsl.Display) _display = (io.intino.konos.dsl.Display) layer;

		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}

			public io.intino.konos.dsl.Block block() {
				io.intino.konos.dsl.Block newElement = core$().graph().concept(io.intino.konos.dsl.Block.class).createNode(this.name, core$()).as(io.intino.konos.dsl.Block.class);

				return newElement;
			}

			public io.intino.konos.dsl.PassiveView.Request request() {
				io.intino.konos.dsl.PassiveView.Request newElement = core$().graph().concept(io.intino.konos.dsl.PassiveView.Request.class).createNode(this.name, core$()).as(io.intino.konos.dsl.PassiveView.Request.class);

				return newElement;
			}

			public io.intino.konos.dsl.PassiveView.Notification notification() {
				io.intino.konos.dsl.PassiveView.Notification newElement = core$().graph().concept(io.intino.konos.dsl.PassiveView.Notification.class).createNode(this.name, core$()).as(io.intino.konos.dsl.PassiveView.Notification.class);

				return newElement;
			}

		}

		public Clear clear() {
			return new Clear();
		}

		public class Clear  {
			public void block(java.util.function.Predicate<io.intino.konos.dsl.Block> filter) {
				new java.util.ArrayList<>(blockList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}

			public void request(java.util.function.Predicate<io.intino.konos.dsl.PassiveView.Request> filter) {
				new java.util.ArrayList<>(requestList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}

			public void notification(java.util.function.Predicate<io.intino.konos.dsl.PassiveView.Notification> filter) {
				new java.util.ArrayList<>(notificationList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}
		}

		public io.intino.konos.dsl.KonosGraph graph() {
			return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
		}
	}


	public io.intino.konos.dsl.KonosGraph graph() {
		return (io.intino.konos.dsl.KonosGraph) core$().graph().as(io.intino.konos.dsl.KonosGraph.class);
	}
}
